# base
ENABLED = 1
DISABLED = 0
ERROR = -1


# Languages Handled for messages
ENG = 'eng'
ITA = 'ita'

# message max length for analyze
MEX_MAX_LENGTH = 70


# situational reply settings
AVOID_REPLY = 0
STD_REPLAY = 1
POWER_REPLAY = 2
STATIC_REPLAY = 3
STATIC_SPLIT_KEY = '&&&'
STATIC_SPLIT_MODE = '%%%'
STATIC_OVERRIDE_MODE = '!'


# CONFIGURATION SETTINGS
# prefix type
NO_PREFIX = -1
COMMAND_PREFIX = 0
OVERRIDE_PREFIX = 1
SUDO_PREFIX = 2

# global setting for auto reply _commands
DISABLED_MODE = 0
QUIET_MODE = 1
NORMAL_MODE = 2
SPAM_MODE = 3
AGGRESSIVE_MODE = 4

# module type, to define the _scope of the module
TYPE_LISTENER = 0
TYPE_COMMAND = 1


# ERRORS CONFIG
# message_reply_error
WRONG_STATIC_MODE_STRING = 1
